# Welcome to MyRocketSimulator!

MyRocketSimulator is a Python library designed to make accurate propagations of rockets and other spacecrafts. From Earth to orbit and beyond.

![GCRF view of satellite with Hohmann transfer to higher altitude](https://raw.githubusercontent.com/ThibaultBS/MyRocketSimulator/main/MRS_examples/MRSoutput/MRSexample3_GCRForbit.svg)

More information and help to be added soon.

## Installation

MRS is available on pypi. Simply execute:

`pip install myrocketsimulator`

